Type Alias BPC
pub type BPC = DAF<BPCSummaryRecord>;Expand description
Binary Planetary Constant
Aliased Type
pub struct BPC {
pub bytes: BytesMut,
pub crc32: Option<u32>,
pub index: HashMap<i32, Vec<(BPCSummaryRecord, Option<usize>, usize)>>,
}Fields
bytes: BytesMutcrc32: Option<u32>CRC32 field enables memory scrubbing, reducing memory errors in a radiation-laden environment.
index: HashMap<i32, Vec<(BPCSummaryRecord, Option<usize>, usize)>>Index of the NAIF ID to its summary record only if all of the summaries for this ID are chronologically ordered. Enables binary search for that ID.